Ossfs
=====

|PyPI| |Status| |Python Version| |License|

|Tests| |Codecov| |pre-commit| |Black|

.. |PyPI| image:: https://img.shields.io/pypi/v/ossfs.svg
   :target: https://pypi.org/project/ossfs/
   :alt: PyPI
.. |Status| image:: https://img.shields.io/pypi/status/ossfs.svg
   :target: https://pypi.org/project/ossfs/
   :alt: Status
.. |Python Version| image:: https://img.shields.io/pypi/pyversions/ossfs
   :target: https://pypi.org/project/ossfs
   :alt: Python Version
.. |License| image:: https://img.shields.io/pypi/l/ossfs
   :target: https://opensource.org/licenses/Apache-2.0
   :alt: License
.. |Tests| image:: https://github.com/karajan1001/ossfs/workflows/Tests/badge.svg
   :target: https://github.com/karajan1001/ossfs/actions?workflow=Tests
   :alt: Tests
.. |Codecov| image:: https://codecov.io/gh/karajan1001/ossfs/branch/main/graph/badge.svg
   :target: https://app.codecov.io/gh/karajan1001/ossfs
   :alt: Codecov
.. |pre-commit| image:: https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit&logoColor=white
   :target: https://github.com/pre-commit/pre-commit
   :alt: pre-commit
.. |Black| image:: https://img.shields.io/badge/code%20style-black-000000.svg
   :target: https://github.com/psf/black
   :alt: Black


Features
--------

* TODO


Requirements
------------

* TODO


Installation
------------

You can install *Ossfs* via pip_ from PyPI_:

.. code:: console

   $ pip install ossfs


Usage
-----


Contributing
------------

Contributions are very welcome.
To learn more, see the `Contributor Guide`_.


License
-------

Distributed under the terms of the `Apache 2.0 license`_,
*Ossfs* is free and open source software.


Issues
------

If you encounter any problems,
please `file an issue`_ along with a detailed description.


.. _Apache 2.0 license: https://opensource.org/licenses/Apache-2.0
.. _PyPI: https://pypi.org/
.. _file an issue: https://github.com/karajan1001/ossfs/issues
.. _pip: https://pip.pypa.io/
.. github-only
.. _Contributor Guide: CONTRIBUTING.rst
